==> supplier-channel-service-api-0.0.63-sources.jar: cn/com/duiba/supplier/channel/service/api/remoteservice/bawangchaji/RemoteQiMaiBaWangChaJiService.java <==
package cn.com.duiba.supplier.channel.service.api.remoteservice.bawangchaji;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.supplier.channel.service.api.dto.request.BaseReq;
import cn.com.duiba.supplier.channel.service.api.dto.request.bawangchaji.CancelQiMaiBaWangChaJiReq;
import cn.com.duiba.supplier.channel.service.api.dto.request.bawangchaji.QiMaiBaWangChaJiReq;
import cn.com.duiba.supplier.channel.service.api.dto.request.bawangchaji.QiMaiCouponReq;
import cn.com.duiba.supplier.channel.service.api.dto.response.BaseResp;
import cn.com.duiba.supplier.channel.service.api.dto.response.bawangchaji.QiMaiCouponCommonResp;
import cn.com.duiba.supplier.channel.service.api.dto.response.bawangchaji.QiMaiCouponResp;

/**
 * 企迈-霸王茶姬
 * @author lizhi
 * @date 2023/4/20 1:44 PM
 */
@AdvancedFeignClient
public interface RemoteQiMaiBaWangChaJiService {

    /**
     * 发放
     * 注意：若结果以mq回调，业务方需要根据业务类型+业务单号幂等<br/>
     * 长时间收不到回调调用查询接口查询<br/>
     * @param request 发放请求参数
     * @return 本次请求是否成功
     */
    BaseResp distribute(BaseReq<QiMaiBaWangChaJiReq> request);

    /**
     * 优惠券作废
     * 注意：若结果以mq回调，业务方需要根据业务类型+业务单号幂等<br/>
     * 长时间收不到回调调用查询接口查询<br/>
     *
     * @param request 发放请求参数
     * @return 本次请求是否成功
     */
    BaseResp cancelOrder(CancelQiMaiBaWangChaJiReq request);


    /**
     * mock核销数据
     * @param request
     */
    void mockVerification(CancelQiMaiBaWangChaJiReq request);

    /**
     * 查询活动列表
     * @param request
     * @return
     * @throws BizException
     */
    QiMaiCouponCommonResp<QiMaiCouponResp> couponActivityList(QiMaiCouponReq request) throws BizException;

}

==> supplier-channel-service-api-0.2.40-sources.jar: cn/com/duiba/supplier/channel/service/api/remoteservice/bawangchaji/RemoteQiMaiBaWangChaJiService.java <==
package cn.com.duiba.supplier.channel.service.api.remoteservice.bawangchaji;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.supplier.channel.service.api.dto.request.BaseReq;
import cn.com.duiba.supplier.channel.service.api.dto.request.bawangchaji.CancelBaWangChaJiReq;
import cn.com.duiba.supplier.channel.service.api.dto.request.bawangchaji.CancelQiMaiBaWangChaJiReq;
import cn.com.duiba.supplier.channel.service.api.dto.request.bawangchaji.QiMaiBaWangChaJiReq;
import cn.com.duiba.supplier.channel.service.api.dto.request.bawangchaji.QiMaiCouponReq;
import cn.com.duiba.supplier.channel.service.api.dto.response.BaseResp;

/**
 * 企迈-霸王茶姬
 * @author lizhi
 * @date 2023/4/20 1:44 PM
 */
@AdvancedFeignClient
public interface RemoteQiMaiBaWangChaJiService {

    /**
     * 发放
     * 注意：若结果以mq回调，业务方需要根据业务类型+业务单号幂等<br/>
     * 长时间收不到回调调用查询接口查询<br/>
     * @param request 发放请求参数
     * @return 本次请求是否成功
     */
    BaseResp distribute(BaseReq<QiMaiBaWangChaJiReq> request);

    /**
     * 优惠券作废
     * 注意：若结果以mq回调，业务方需要根据业务类型+业务单号幂等<br/>
     * 长时间收不到回调调用查询接口查询<br/>
     *
     * @param request 发放请求参数
     * @return 本次请求是否成功
     */
    BaseResp cancelOrder(CancelBaWangChaJiReq request);


    /**
     * mock核销数据
     * @param request
     */
    void mockVerification(CancelQiMaiBaWangChaJiReq request);

    /**
     * 查询活动列表
     * @param request
     * @return
     * @throws BizException
     */
    String couponActivityList(QiMaiCouponReq request) throws BizException;

}
